summaryrefslogtreecommitdiffstats
path: root/test/test.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/test.c')
-rw-r--r--test/test.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/test.c b/test/test.c
index 2e1518a08..5506cbd11 100644
--- a/test/test.c
+++ b/test/test.c
@@ -236,7 +236,7 @@ static void PrintTitleInfo( hb_title_t * title )
}
else
{
- fprintf( stderr, " + %d, %s\n", i, audio->lang );
+ fprintf( stderr, " + %d, %s\n", i + 1, audio->lang );
}
}
fprintf( stderr, " + subtitle tracks:\n" );
@@ -980,9 +980,9 @@ static int CheckOptions( int argc, char ** argv )
}
}
- if (acodec != HB_ACODEC_FAAC)
+ if (acodec != HB_ACODEC_FAAC && acodec != HB_ACODEC_VORBIS)
{
/* only attempt 5.1 export if exporting to AAC */
surround = 0;
} else {
if (!abitrate && surround)
@@ -980,9 +980,9 @@ static int CheckOptions( int argc, char ** argv )
{
- /* only attempt 5.1 export if exporting to AAC */
+ /* only attempt 5.1 export if exporting to AAC or Vorbis */
surround = 0;
} else {